From 8bdd80abfa3830142b16615d97d555dad417e08d Mon Sep 17 00:00:00 2001
From: Diva Canto
Date: Thu, 12 Jan 2012 09:56:35 -0800
Subject: HG: normalize all externalized user ULRs to be the Home URL, i.e. the
location of the user's UAS. This corrects an earlier design which had some
cases pointing to the profile server. WARNING: CONFIGURATION CHANGES in both
the sims (*Common.ini) and the Robust configs (Robust.HG.ini). Please check
diff of the example files, but basically all vars that were pointing to
profile should point to the UAS instead and should be called HomeURI.
---
.../Serialization/External/ExternalRepresentationUtils.cs | 8 ++++----
1 file changed, 4 insertions(+), 4 deletions(-)
(limited to 'OpenSim/Framework/Serialization/External/ExternalRepresentationUtils.cs')
diff --git a/OpenSim/Framework/Serialization/External/ExternalRepresentationUtils.cs b/OpenSim/Framework/Serialization/External/ExternalRepresentationUtils.cs
index 6e8c2ee..7447ac2 100644
--- a/OpenSim/Framework/Serialization/External/ExternalRepresentationUtils.cs
+++ b/OpenSim/Framework/Serialization/External/ExternalRepresentationUtils.cs
@@ -44,13 +44,13 @@ namespace OpenSim.Framework.Serialization.External
/// with creator data added to it.
///
/// The SceneObjectPart represented in XML2
/// The URL of the profile service for the creator
/// The service for retrieving user account information
/// The scope of the user account information (Grid ID)
/// The SceneObjectPart represented in XML2
- public static string RewriteSOP(string xml, string profileURL, IUserAccountService userService, UUID scopeID)
+ public static string RewriteSOP(string xml, string homeURL, IUserAccountService userService, UUID scopeID)
{
- if (xml == string.Empty || profileURL == string.Empty || userService == null)
+ if (xml == string.Empty || homeURL == string.Empty || userService == null)
return xml;
XmlDocument doc = new XmlDocument();
@@ -83,7 +83,7 @@ namespace OpenSim.Framework.Serialization.External
if (!hasCreatorData && creator != null)
{
XmlElement creatorData = doc.CreateElement("CreatorData");
- creatorData.InnerText = profileURL + "/" + creator.PrincipalID + ";" + creator.FirstName + " " + creator.LastName;
+ creatorData.InnerText = homeURL + ";" + creator.FirstName + " " + creator.LastName;
sop.AppendChild(creatorData);
}
}
@@ -44,13 +44,13 @@ namespace OpenSim.Framework.Serialization.External
///
/// The SceneObjectPart represented in XML2
- /// The URL of the profile service for the creator
+ /// The URL of the user agents service (home) for the creator
/// The service for retrieving user account information
/// The scope of the user account information (Grid ID)
--
cgit v1.1